==> aws-android-sdk-core-2.12.2-sources.jar: com/amazonaws/services/cognitoidentity/model/transform/CreateIdentityPoolRequestMarshaller.java <==
/*
 * Copyright 2010-2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.cognitoidentity.model.transform;

import static com.amazonaws.util.StringUtils.UTF8;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.OutputStreamWriter;
import java.io.StringWriter;
import java.io.Writer;

import com.amazonaws.AmazonClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.cognitoidentity.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.AwsJsonWriter;
import com.amazonaws.util.json.JsonUtils;

/**
 * JSON request marshaller for CreateIdentityPoolRequest
 */
public class CreateIdentityPoolRequestMarshaller implements
        Marshaller<Request<CreateIdentityPoolRequest>, CreateIdentityPoolRequest> {

    public Request<CreateIdentityPoolRequest> marshall(
            CreateIdentityPoolRequest createIdentityPoolRequest) {
        if (createIdentityPoolRequest == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(CreateIdentityPoolRequest)");
        }

        Request<CreateIdentityPoolRequest> request = new DefaultRequest<CreateIdentityPoolRequest>(
                createIdentityPoolRequest, "AmazonCognitoIdentity");
        String target = "AWSCognitoIdentityService.CreateIdentityPool";
        request.addHeader("X-Amz-Target", target);
        request.setHttpMethod(HttpMethodName.POST);

        String uriResourcePath = "/";
        request.setResourcePath(uriResourcePath);
        try {
            StringWriter stringWriter = new StringWriter();
            AwsJsonWriter jsonWriter = JsonUtils.getJsonWriter(stringWriter);
            jsonWriter.beginObject();

            if (createIdentityPoolRequest.getIdentityPoolName() != null) {
                String identityPoolName = createIdentityPoolRequest.getIdentityPoolName();
                jsonWriter.name("IdentityPoolName");
                jsonWriter.value(identityPoolName);
            }
            if (createIdentityPoolRequest.getAllowUnauthenticatedIdentities() != null) {
                Boolean allowUnauthenticatedIdentities = createIdentityPoolRequest
                        .getAllowUnauthenticatedIdentities();
                jsonWriter.name("AllowUnauthenticatedIdentities");
                jsonWriter.value(allowUnauthenticatedIdentities);
            }
            if (createIdentityPoolRequest.getSupportedLoginProviders() != null) {
                java.util.Map<String, String> supportedLoginProviders = createIdentityPoolRequest
                        .getSupportedLoginProviders();
                jsonWriter.name("SupportedLoginProviders");
                jsonWriter.beginObject();
                for (java.util.Map.Entry<String, String> supportedLoginProvidersEntry : supportedLoginProviders
                        .entrySet()) {
                    String supportedLoginProvidersValue = supportedLoginProvidersEntry.getValue();
                    if (supportedLoginProvidersValue != null) {
                        jsonWriter.name(supportedLoginProvidersEntry.getKey());
                        jsonWriter.value(supportedLoginProvidersValue);
                    }
                }
                jsonWriter.endObject();
            }
            if (createIdentityPoolRequest.getDeveloperProviderName() != null) {
                String developerProviderName = createIdentityPoolRequest.getDeveloperProviderName();
                jsonWriter.name("DeveloperProviderName");
                jsonWriter.value(developerProviderName);
            }
            if (createIdentityPoolRequest.getOpenIdConnectProviderARNs() != null) {
                java.util.List<String> openIdConnectProviderARNs = createIdentityPoolRequest
                        .getOpenIdConnectProviderARNs();
                jsonWriter.name("OpenIdConnectProviderARNs");
                jsonWriter.beginArray();
                for (String openIdConnectProviderARNsItem : openIdConnectProviderARNs) {
                    if (openIdConnectProviderARNsItem != null) {
                        jsonWriter.value(openIdConnectProviderARNsItem);
                    }
                }
                jsonWriter.endArray();
            }
            if (createIdentityPoolRequest.getCognitoIdentityProviders() != null) {
                java.util.List<CognitoIdentityProvider> cognitoIdentityProviders = createIdentityPoolRequest
                        .getCognitoIdentityProviders();
                jsonWriter.name("CognitoIdentityProviders");
                jsonWriter.beginArray();
                for (CognitoIdentityProvider cognitoIdentityProvidersItem : cognitoIdentityProviders) {
                    if (cognitoIdentityProvidersItem != null) {
                        CognitoIdentityProviderJsonMarshaller.getInstance().marshall(
                                cognitoIdentityProvidersItem, jsonWriter);
                    }
                }
                jsonWriter.endArray();
            }
            if (createIdentityPoolRequest.getSamlProviderARNs() != null) {
                java.util.List<String> samlProviderARNs = createIdentityPoolRequest
                        .getSamlProviderARNs();
                jsonWriter.name("SamlProviderARNs");
                jsonWriter.beginArray();
                for (String samlProviderARNsItem : samlProviderARNs) {
                    if (samlProviderARNsItem != null) {
                        jsonWriter.value(samlProviderARNsItem);
                    }
                }
                jsonWriter.endArray();
            }

            jsonWriter.endObject();
            jsonWriter.close();
            String snippet = stringWriter.toString();
            byte[] content = snippet.getBytes(UTF8);
            request.setContent(new StringInputStream(snippet));
            request.addHeader("Content-Length", Integer.toString(content.length));
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
        if (!request.getHeaders().containsKey("Content-Type")) {
            request.addHeader("Content-Type", "application/x-amz-json-1.1");
        }

        return request;
    }
}

==> aws-android-sdk-core-2.13.6-sources.jar: com/amazonaws/services/cognitoidentity/model/transform/CreateIdentityPoolRequestMarshaller.java <==
/*
 * Copyright 2010-2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.cognitoidentity.model.transform;

import static com.amazonaws.util.StringUtils.UTF8;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.OutputStreamWriter;
import java.io.StringWriter;
import java.io.Writer;

import com.amazonaws.AmazonClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.cognitoidentity.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.AwsJsonWriter;
import com.amazonaws.util.json.JsonUtils;

/**
 * JSON request marshaller for CreateIdentityPoolRequest
 */
public class CreateIdentityPoolRequestMarshaller implements
        Marshaller<Request<CreateIdentityPoolRequest>, CreateIdentityPoolRequest> {

    public Request<CreateIdentityPoolRequest> marshall(
            CreateIdentityPoolRequest createIdentityPoolRequest) {
        if (createIdentityPoolRequest == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(CreateIdentityPoolRequest)");
        }

        Request<CreateIdentityPoolRequest> request = new DefaultRequest<CreateIdentityPoolRequest>(
                createIdentityPoolRequest, "AmazonCognitoIdentity");
        String target = "AWSCognitoIdentityService.CreateIdentityPool";
        request.addHeader("X-Amz-Target", target);
        request.setHttpMethod(HttpMethodName.POST);

        String uriResourcePath = "/";
        request.setResourcePath(uriResourcePath);
        try {
            StringWriter stringWriter = new StringWriter();
            AwsJsonWriter jsonWriter = JsonUtils.getJsonWriter(stringWriter);
            jsonWriter.beginObject();

            if (createIdentityPoolRequest.getIdentityPoolName() != null) {
                String identityPoolName = createIdentityPoolRequest.getIdentityPoolName();
                jsonWriter.name("IdentityPoolName");
                jsonWriter.value(identityPoolName);
            }
            if (createIdentityPoolRequest.getAllowUnauthenticatedIdentities() != null) {
                Boolean allowUnauthenticatedIdentities = createIdentityPoolRequest
                        .getAllowUnauthenticatedIdentities();
                jsonWriter.name("AllowUnauthenticatedIdentities");
                jsonWriter.value(allowUnauthenticatedIdentities);
            }
            if (createIdentityPoolRequest.getSupportedLoginProviders() != null) {
                java.util.Map<String, String> supportedLoginProviders = createIdentityPoolRequest
                        .getSupportedLoginProviders();
                jsonWriter.name("SupportedLoginProviders");
                jsonWriter.beginObject();
                for (java.util.Map.Entry<String, String> supportedLoginProvidersEntry : supportedLoginProviders
                        .entrySet()) {
                    String supportedLoginProvidersValue = supportedLoginProvidersEntry.getValue();
                    if (supportedLoginProvidersValue != null) {
                        jsonWriter.name(supportedLoginProvidersEntry.getKey());
                        jsonWriter.value(supportedLoginProvidersValue);
                    }
                }
                jsonWriter.endObject();
            }
            if (createIdentityPoolRequest.getDeveloperProviderName() != null) {
                String developerProviderName = createIdentityPoolRequest.getDeveloperProviderName();
                jsonWriter.name("DeveloperProviderName");
                jsonWriter.value(developerProviderName);
            }
            if (createIdentityPoolRequest.getOpenIdConnectProviderARNs() != null) {
                java.util.List<String> openIdConnectProviderARNs = createIdentityPoolRequest
                        .getOpenIdConnectProviderARNs();
                jsonWriter.name("OpenIdConnectProviderARNs");
                jsonWriter.beginArray();
                for (String openIdConnectProviderARNsItem : openIdConnectProviderARNs) {
                    if (openIdConnectProviderARNsItem != null) {
                        jsonWriter.value(openIdConnectProviderARNsItem);
                    }
                }
                jsonWriter.endArray();
            }
            if (createIdentityPoolRequest.getCognitoIdentityProviders() != null) {
                java.util.List<CognitoIdentityProvider> cognitoIdentityProviders = createIdentityPoolRequest
                        .getCognitoIdentityProviders();
                jsonWriter.name("CognitoIdentityProviders");
                jsonWriter.beginArray();
                for (CognitoIdentityProvider cognitoIdentityProvidersItem : cognitoIdentityProviders) {
                    if (cognitoIdentityProvidersItem != null) {
                        CognitoIdentityProviderJsonMarshaller.getInstance().marshall(
                                cognitoIdentityProvidersItem, jsonWriter);
                    }
                }
                jsonWriter.endArray();
            }
            if (createIdentityPoolRequest.getSamlProviderARNs() != null) {
                java.util.List<String> samlProviderARNs = createIdentityPoolRequest
                        .getSamlProviderARNs();
                jsonWriter.name("SamlProviderARNs");
                jsonWriter.beginArray();
                for (String samlProviderARNsItem : samlProviderARNs) {
                    if (samlProviderARNsItem != null) {
                        jsonWriter.value(samlProviderARNsItem);
                    }
                }
                jsonWriter.endArray();
            }
            if (createIdentityPoolRequest.getIdentityPoolTags() != null) {
                java.util.Map<String, String> identityPoolTags = createIdentityPoolRequest
                        .getIdentityPoolTags();
                jsonWriter.name("IdentityPoolTags");
                jsonWriter.beginObject();
                for (java.util.Map.Entry<String, String> identityPoolTagsEntry : identityPoolTags
                        .entrySet()) {
                    String identityPoolTagsValue = identityPoolTagsEntry.getValue();
                    if (identityPoolTagsValue != null) {
                        jsonWriter.name(identityPoolTagsEntry.getKey());
                        jsonWriter.value(identityPoolTagsValue);
                    }
                }
                jsonWriter.endObject();
            }

            jsonWriter.endObject();
            jsonWriter.close();
            String snippet = stringWriter.toString();
            byte[] content = snippet.getBytes(UTF8);
            request.setContent(new StringInputStream(snippet));
            request.addHeader("Content-Length", Integer.toString(content.length));
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
        if (!request.getHeaders().containsKey("Content-Type")) {
            request.addHeader("Content-Type", "application/x-amz-json-1.1");
        }

        return request;
    }
}
